Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.kernel > #1345333

[PATCH 4/7] regulator: act8865: Rename platform_data field to init_data

From Maarten ter Huurne <maarten@treewalker.org>
Newsgroups linux.kernel
Subject [PATCH 4/7] regulator: act8865: Rename platform_data field to init_data
Date 2016-02-28 17:00 +0100
Message-ID <r7bVh-4Ib-15@gated-at.bofh.it> (permalink)
References <r7bVf-4Ib-3@gated-at.bofh.it>
Organization linux.* mail to news gateway

Show all headers | View raw


Make the field name match its type.

Signed-off-by: Maarten ter Huurne <maarten@treewalker.org>
---
 drivers/regulator/act8865-regulator.c | 4 ++--
 include/linux/regulator/act8865.h     | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/regulator/act8865-regulator.c b/drivers/regulator/act8865-regulator.c
index 477d60c..0d1b235 100644
--- a/drivers/regulator/act8865-regulator.c
+++ b/drivers/regulator/act8865-regulator.c
@@ -418,7 +418,7 @@ static int act8865_pdata_from_dt(struct device *dev,
 	for (i = 0; i < num_matches; i++) {
 		regulator->id = i;
 		regulator->name = matches[i].name;
-		regulator->platform_data = matches[i].init_data;
+		regulator->init_data = matches[i].init_data;
 		of_node[i] = matches[i].of_node;
 		regulator++;
 	}
@@ -445,7 +445,7 @@ static struct regulator_init_data
 
 	for (i = 0; i < pdata->num_regulators; i++) {
 		if (pdata->regulators[i].id == id)
-			return pdata->regulators[i].platform_data;
+			return pdata->regulators[i].init_data;
 	}
 
 	return NULL;
diff --git a/include/linux/regulator/act8865.h b/include/linux/regulator/act8865.h
index 15fa8f2..2eb3860 100644
--- a/include/linux/regulator/act8865.h
+++ b/include/linux/regulator/act8865.h
@@ -68,12 +68,12 @@ enum {
  * act8865_regulator_data - regulator data
  * @id: regulator id
  * @name: regulator name
  * @platform_data: regulator init data
  */
 struct act8865_regulator_data {
 	int id;
 	const char *name;
-	struct regulator_init_data *platform_data;
+	struct regulator_init_data *init_data;
 };
 
 /**
@@ -68,12 +68,12 @@ enum {
  * @id: regulator id
  * @name: regulator name
- * @platform_data: regulator init data
+ * @init_data: regulator init data
  */
 struct act8865_regulator_data {
-- 
2.6.2

Back to linux.kernel | Previous | NextPrevious in thread | Next in thread | Find similar | Unroll thread


Thread

[PATCH 1/7] regulator: act8865: Expose act8600 registers via debugfs Maarten ter Huurne <maarten@treewalker.org> - 2016-02-28 17:00 +0100
  [PATCH 4/7] regulator: act8865: Rename platform_data field to init_data Maarten ter Huurne <maarten@treewalker.org> - 2016-02-28 17:00 +0100
  [PATCH 2/7] regulator: act8865: Remove redundant dev lookups Maarten ter Huurne <maarten@treewalker.org> - 2016-02-28 17:00 +0100
  Re: [PATCH 1/7] regulator: act8865: Expose act8600 registers via  debugfs Mark Brown <broonie@kernel.org> - 2016-02-29 12:30 +0100

csiph-web